"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DropIndexBuilder = void 0;
const drop_index_node_js_1 = require("../operation-node/drop-index-node.js");
const prevent_await_js_1 = require("../util/prevent-await.js");
const table_parser_js_1 = require("../parser/table-parser.js");
const object_utils_js_1 = require("../util/object-utils.js");
class DropIndexBuilder {
    #props;
    constructor(props) {
        this.#props = (0, object_utils_js_1.freeze)(props);
    }
    /**
     * Specifies the table the index was created for. This is not needed
     * in all dialects.
     */
    on(table) {
        return new DropIndexBuilder({
            ...this.#props,
            dropIndexNode: drop_index_node_js_1.DropIndexNode.cloneWith(this.#props.dropIndexNode, {
                table: (0, table_parser_js_1.parseTable)(table),
            }),
        });
    }
    ifExists() {
        return new DropIndexBuilder({
            ...this.#props,
            dropIndexNode: drop_index_node_js_1.DropIndexNode.cloneWith(this.#props.dropIndexNode, {
                ifExists: true,
            }),
        });
    }
    toOperationNode() {
        return this.#props.executor.transformQuery(this.#props.dropIndexNode, this.#props.queryId);
    }
    compile() {
        return this.#props.executor.compileQuery(this.toOperationNode(), this.#props.queryId);
    }
    async execute() {
        await this.#props.executor.executeQuery(this.compile(), this.#props.queryId);
    }
}
exports.DropIndexBuilder = DropIndexBuilder;
(0, prevent_await_js_1.preventAwait)(DropIndexBuilder, "don't await DropIndexBuilder instances directly. To execute the query you need to call `execute`");
